# Contributing

We love pull requests. Here's a quick guide.

Fork, then clone the repo:

    git clone git@github.com:your-username/qmon.git

Set up your machine:


Make your change. Add tests for your change. Make the tests pass:

Push to your fork and [submit a pull request][pr].

[pr]: https://github.com/shubhamchaudhary/qmon/compare/

At this point you're waiting on us. We will not disappoint you.

Some things that we'd love to see in your pull request are:

* Follow coding style of the current source code.
* Write a good commit message.

#### List of available tasks:  
* Search the application for TODO tags. (Tip: Use ack-grep)  
* Add more programming languages  
* Handle situations when software not installed  
* Stricter requirements
* Evolve follow.py

